# spkg

SPKG (Simple Packager) - A command line tools for building and uploading python packages.

[![PyPI - Version](https://img.shields.io/pypi/v/spkg.svg)](https://pypi.org/project/spkg)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/spkg.svg)](https://pypi.org/project/spkg)

-----

**Table of Contents**

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```console
pip install spkg
```

## Usage

Type `spkg -h` to see the help message.

Type `spkg [COMMAND] -h` to see the help message for a specific command.

## License

`spkg` is distributed under the terms of the [GPL-3.0-only](https://spdx.org/licenses/GPL-3.0-only.html) license.
